@@ -32,9 +32,9 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 BlueprintValidationResponse, AccountRepositoryDetailsResponse,
                                                 DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse,
                                                 ParameterStoreItem, RepositoryProviderResponse,
-                                                RepositoryRelationshipResponse, AccountExtraDetails, CustomTagResponse,
+                                                RepositoryRelationshipResponse, AccountExtraDetails,
                                                 TerraformModuleDescriptorResponse, CustomTagOverrideResponse,
-                                                SpaceTerraformModuleResponse)
+                                                SpaceTerraformModuleResponse, CustomTagWithStatisticsResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -422,16 +422,18 @@ class Colony:
 
     def list_blueprints(
             self, exclude_samples=False, deployment_type: str = None,
-            branch: str = None, commit: str = None
+            branch: str = None, commit: str = None, space_name: str = None
     ) -> List[BlueprintResponse]:
         params = {}
+        selected_space = space_name or self.space
+
         if deployment_type:
             params["type"] = deployment_type
         if branch:
             params["branch"] = branch
         if commit:
             params["commit"] = commit
-        method_url = self._api_root.blueprint.blueprints_by_space_name(self.space)
+        method_url = self._api_root.blueprint.blueprints_by_space_name(selected_space)
         resp = self.session.get(url=method_url, params=params)
         GatewayUtils.handle_response(response=resp, return_codes=[200, 400, 404])
         if resp.status_code in [400, 404]:
@@ -1586,12 +1588,16 @@ class Colony:
         GatewayUtils.handle_response(response=res, return_codes=[200])
         return json.loads(res.text)
 
-    def get_custom_tags(self) -> List[CustomTagResponse]:
+    def get_custom_tags(self, filter_pre_defined: bool = True) -> List[CustomTagWithStatisticsResponse]:
         method_url = self._api_root.settings.custom_tags()
         res = self.session.get(url=method_url)
         GatewayUtils.handle_response(response=res, return_codes=[200])
         custom_tags_json = json.loads(res.text)
-        return [Converters.create_custom_tag_response(custom_tag) for custom_tag in custom_tags_json]
+        custom_tag_list = [Converters.create_custom_tag_with_statistics_response(custom_tag) for custom_tag in
+                           custom_tags_json]
+        if filter_pre_defined:
+            custom_tag_list = list(filter(lambda x: (x.tag_type != 'pre_defined'), custom_tag_list))
+        return custom_tag_list
 
     def create_custom_tag(self, name: str, value: str, scope: str, possible_values: [], description: str):
         method_url = self._api_root.settings.custom_tags()
