@@ -45,7 +45,7 @@ from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccount
                                                 TerraformModuleDescriptorResponse, CustomTagResponse,
                                                 CustomTagOverrideResponse, ServiceTfLogsResponse,
                                                 ServiceTfLogInfo, SpaceTerraformModuleResponse, BlueprintTagResponse,
-                                                AccountRepositoryItemResponse)
+                                                AccountRepositoryItemResponse, CustomTagWithStatisticsResponse)
 
 
 class Converters:
@@ -89,7 +89,10 @@ class Converters:
             url=catalog["url"],
             last_modified=catalog["last_modified"],
             modified_by=catalog["modified_by"],
-            clouds=catalog["clouds"] if catalog["clouds"] else [],
+            clouds=[
+                Converters._create_blueprint_cloud_response(cloud)
+                for cloud in catalog["clouds"]
+            ],
             applications=[
                 Converters._create_catalog_app_response(app)
                 for app in catalog["applications"]
@@ -122,7 +125,10 @@ class Converters:
             url=catalog["url"],
             last_modified=catalog["last_modified"],
             modified_by=catalog["modified_by"],
-            clouds=catalog["clouds"] if catalog["clouds"] else [],
+            clouds=[
+                Converters._create_blueprint_cloud_response(cloud)
+                for cloud in catalog["clouds"]
+            ],
             links=[Converters._create_link_response(link) for link in catalog["links"]]
             if catalog["links"]
             else [],
@@ -1224,6 +1230,25 @@ class Converters:
             created_date=data['created_date']
         )
 
+    @staticmethod
+    def create_custom_tag_with_statistics_response(data: dict) -> CustomTagWithStatisticsResponse:
+        return CustomTagWithStatisticsResponse(
+            name=data['name'],
+            value=data['value'],
+            scope=data['scope'],
+            possible_values=data['possible_values'],
+            description=data['description'],
+            modified_by=data['modified_by'],
+            last_modified=data['last_modified'],
+            created_by=data['created_by'],
+            created_date=data['created_date'],
+            tag_type=data['tag_type'],
+            overridden_values=data['overridden_values'],
+            missing_overrides=data['missing_overrides'],
+            missing_overrides_space=data['missing_overrides_space'],
+            missing_overrides_sandbox_blueprints=data['missing_overrides_sandbox_blueprints'],
+            missing_overrides_production_blueprints=data['missing_overrides_production_blueprints'])
+
     @staticmethod
     def create_custom_tag_response_list(custom_tags: Optional[List[dict]]) -> Optional[List[CustomTagResponse]]:
         if custom_tags is None:
