@@ -110,60 +110,6 @@ class CatalogApplicationResponse:
         self.version = version
 
 
-class CatalogForGetResponse:
-    def __init__(
-            self,
-            name: str,
-            description: str,
-            url: str,
-            last_modified: str,
-            modified_by: str,
-            clouds: List[str],
-            applications: List[CatalogApplicationResponse],
-            links: List[HyperlinkResponse],
-            artifacts: Dict[str, str],
-            errors: [],
-            tags: List[BlueprintTagResponse],
-    ):
-        self.errors = errors
-        self.links = links
-        self.url = url
-        self.description = description
-        self.name = name
-        self.last_modified = last_modified
-        self.modified_by = modified_by
-        self.clouds = clouds
-        self.applications = applications
-        self.artifacts = artifacts
-        self.tags = tags
-
-
-class CatalogForGetAllResponse:
-    def __init__(
-            self,
-            name: str,
-            description: str,
-            url: str,
-            last_modified: str,
-            modified_by: str,
-            clouds: List[str],
-            links: List[HyperlinkResponse],
-            artifacts: Dict[str, str],
-            errors: [],
-            tags: List[BlueprintTagResponse],
-    ):
-        self.links = links
-        self.url = url
-        self.description = description
-        self.name = name
-        self.last_modified = last_modified
-        self.modified_by = modified_by
-        self.clouds = clouds
-        self.artifacts = artifacts
-        self.errors = errors
-        self.tags = tags
-
-
 class BlueprintApplicationResponse:
     def __init__(self, name: str, version: str):
         self.name = name
@@ -274,6 +220,60 @@ class BlueprintResponse:
         self.tags = tags
 
 
+class CatalogForGetResponse:
+    def __init__(
+            self,
+            name: str,
+            description: str,
+            url: str,
+            last_modified: str,
+            modified_by: str,
+            clouds: List[BlueprintCloudResponse],
+            applications: List[CatalogApplicationResponse],
+            links: List[HyperlinkResponse],
+            artifacts: Dict[str, str],
+            errors: [],
+            tags: List[BlueprintTagResponse],
+    ):
+        self.errors = errors
+        self.links = links
+        self.url = url
+        self.description = description
+        self.name = name
+        self.last_modified = last_modified
+        self.modified_by = modified_by
+        self.clouds = clouds
+        self.applications = applications
+        self.artifacts = artifacts
+        self.tags = tags
+
+
+class CatalogForGetAllResponse:
+    def __init__(
+            self,
+            name: str,
+            description: str,
+            url: str,
+            last_modified: str,
+            modified_by: str,
+            clouds: List[BlueprintCloudResponse],
+            links: List[HyperlinkResponse],
+            artifacts: Dict[str, str],
+            errors: [],
+            tags: List[BlueprintTagResponse],
+    ):
+        self.links = links
+        self.url = url
+        self.description = description
+        self.name = name
+        self.last_modified = last_modified
+        self.modified_by = modified_by
+        self.clouds = clouds
+        self.artifacts = artifacts
+        self.errors = errors
+        self.tags = tags
+
+
 class SourceControlDetailsResponse:
     def __init__(
             self,
@@ -542,7 +542,7 @@ class ServiceResponse:
         self.status = status
         self.progress = progress
         self.logs = logs
-        
+
 
 class CustomTagResponse:
     def __init__(self,
@@ -554,7 +554,7 @@ class CustomTagResponse:
                  modified_by: str,
                  last_modified: datetime,
                  created_by: str,
-                 created_date: datetime,
+                 created_date: datetime
                  ):
         self.name = name
         self.value = value
@@ -567,6 +567,40 @@ class CustomTagResponse:
         self.created_by = created_by
 
 
+class CustomTagWithStatisticsResponse(CustomTagResponse):
+    def __init__(self,
+                 name: str,
+                 value: str,
+                 scope: str,
+                 possible_values: [],
+                 description: str,
+                 modified_by: str,
+                 last_modified: datetime,
+                 created_by: str,
+                 created_date: datetime,
+                 tag_type: str,
+                 overridden_values: int,
+                 missing_overrides: int,
+                 missing_overrides_space: List[str],
+                 missing_overrides_sandbox_blueprints: List[str],
+                 missing_overrides_production_blueprints: List[str]):
+        super().__init__(name,
+                         value,
+                         scope,
+                         possible_values,
+                         description,
+                         modified_by,
+                         last_modified,
+                         created_by,
+                         created_date)
+        self.tag_type = tag_type
+        self.overridden_values = overridden_values
+        self.missing_overrides = missing_overrides
+        self.missing_overrides_space = missing_overrides_space
+        self.missing_overrides_sandbox_blueprints = missing_overrides_sandbox_blueprints
+        self.missing_overrides_production_blueprints = missing_overrides_production_blueprints
+
+
 class SandboxResponse(SandboxResponseBase):
     def __init__(self,
                  sandbox_id: str,
